==> node-appc-0.2.0.tgz: package/locales/en.js <==
{
	"Error communicating with the server: %s": "Error communicating with the server: %s",
	"Server did not return a session cookie": "Server did not return a session cookie",
	"Invalid username or password. If you have forgotten your password, please visit %s.": "Invalid username or password. If you have forgotten your password, please visit %s.",
	"Invalid server response": "Invalid server response",
	"Error logging out from server: %s": "Error logging out from server: %s",
	"Session file \"%s\" is not writable": "Session file \"%s\" is not writable",
	"Please ensure the Titanium CLI has access to modify this file.": "Please ensure the Titanium CLI has access to modify this file.",
	"Directory \"%s\" is not writable": "Directory \"%s\" is not writable",
	"Please ensure the Titanium CLI has access to this directory.": "Please ensure the Titanium CLI has access to this directory.",
	"The Command Line Tools are not installed": "The Command Line Tools are not installed",
	"Titanium requires that the Command Line Tools be installed to develop __Tizen apps__ or __native Android modules__.": "Titanium requires that the Command Line Tools be installed to develop __Tizen apps__ or __native Android modules__.",
	"You can install them from the Xcode Preferences > Downloads tab or by visiting": "You can install them from the Xcode Preferences > Downloads tab or by visiting",
	"Copying %s => %s": "Copying %s => %s",
	"Symlinking %s => %s": "Symlinking %s => %s",
	"Resizing images: %s": "Resizing images: %s",
	"Java Development Kit not installed.": "Java Development Kit not installed.",
	"Mac OS X 10.7 (Lion) and newer do not include the JDK and must be manually downloaded and installed from %s.": "Mac OS X 10.7 (Lion) and newer do not include the JDK and must be manually downloaded and installed from %s.",
	"JDK (Java Development Kit) not installed.": "JDK (Java Development Kit) not installed.",
	"If you already have installed the JDK, verify your __JAVA_HOME__ environment variable is correctly set.": "If you already have installed the JDK, verify your __JAVA_HOME__ environment variable is correctly set.",
	"The JDK is required for must be manually downloaded and installed from %s.": "The JDK is required for must be manually downloaded and installed from %s.",
	"Unable to find JDK (Java Development Kit) programs: %s": "Unable to find JDK (Java Development Kit) programs: %s",
	"Please verify your __JAVA_HOME__ environment variable is correctly set to the JDK install location.": "Please verify your __JAVA_HOME__ environment variable is correctly set to the JDK install location.",
	"__JAVA_HOME__ is currently set to \"%s\".": "__JAVA_HOME__ is currently set to \"%s\".",
	"Please set the __JAVA_HOME__ is set to the JDK install location and not the JRE (Java Runtime Environment).": "Please set the __JAVA_HOME__ is set to the JDK install location and not the JRE (Java Runtime Environment).",
	"The __JAVA_HOME__ must point to the JDK and not the JRE (Java Runtime Environment).": "The __JAVA_HOME__ must point to the JDK and not the JRE (Java Runtime Environment).",
	"You may want to reinstall the JDK by downloading it from %s.": "You may want to reinstall the JDK by downloading it from %s.",
	"Unable to find a valid Java installation containing a libjvm.so": "Unable to find a valid Java installation containing a libjvm.so",
	"Did you mean this?": "Did you mean this?",
	"day": {
		"one": "day",
		"other": "days"
	},
	"hour": {
		"one": "hour",
		"other": "hours"
	},
	"minute": {
		"one": "minute",
		"other": "minutes"
	},
	"second": {
		"one": "second",
		"other": "seconds"
	},
	"Looking for Titanium module id=%s version=%s platform=%s deploy-type=%s": "Looking for Titanium module id=%s version=%s platform=%s deploy-type=%s",
	"Found incompatible Titanium module id=%s version=%s platform=%s deploy-type=%s": "Found incompatible Titanium module id=%s version=%s platform=%s deploy-type=%s",
	"Found better matching module id=%s version=%s platform=%s deploy-type=%s path=%s": "Found better matching module id=%s version=%s platform=%s deploy-type=%s path=%s",
	"Found Titanium module id=%s version=%s platform=%s deploy-type=%s path=%s": "Found Titanium module id=%s version=%s platform=%s deploy-type=%s path=%s",
	"Could not find Titanium module id=%s version=%s platform=%s deploy-type=%s": "Could not find Titanium module id=%s version=%s platform=%s deploy-type=%s",
	"Installing module: %s": "Installing module: %s",
	"Failed to unzip module \"%s\"": "Failed to unzip module \"%s\"",
	"Detecting modules in %s": "Detecting modules in %s",
	"Detected %s module: %s %s @ %s": "Detected %s module: %s %s @ %s",
	"Looking for Titanium plugin id=%s version=%s": "Looking for Titanium plugin id=%s version=%s",
	"Found Titanium plugin id=%s version=%s ": "Found Titanium plugin id=%s version=%s ",
	"Could not find Titanium plugin id=%s version=%s": "Could not find Titanium plugin id=%s version=%s",
	"Detecting plugins in %s": "Detecting plugins in %s",
	"Detected plugin: %s @ %s": "Detected plugin: %s @ %s",
	"Detected plugin: %s %s @ %s": "Detected plugin: %s %s @ %s"
}

==> node-appc-1.1.7.tgz: package/locales/en.js <==
{
	"Processing analytics": "Processing analytics",
	"Titanium home directory: %s": "Titanium home directory: %s",
	"Machine ID: %s": "Machine ID: %s",
	"Creating Titanium home directory": "Creating Titanium home directory",
	"Creating analytics events directory": "Creating analytics events directory",
	"Writing event to file: %s": "Writing event to file: %s",
	"Reading session file: %s": "Reading session file: %s",
	"Session is valid": "Session is valid",
	"Session expired, adding ti.end event": "Session expired, adding ti.end event",
	"Creating new session": "Creating new session",
	"Adding ti.start event": "Adding ti.start event",
	"Adding %%s event": {
		"one": "Adding %%s event",
		"other": "Adding %%s events"
	},
	"Updating session file": "Updating session file",
	"Forking analytics send process": "Forking analytics send process",
	"Not logged in or no user guid, skipping send analytics": "Not logged in or no user guid, skipping send analytics",
	"Analytics send process": "Analytics send process",
	"Analytics URL: %s": "Analytics URL: %s",
	"Analytics events directory: %s": "Analytics events directory: %s",
	"pid file: %s": "pid file: %s",
	"pid file exists, check if pid %s is running": "pid file exists, check if pid %s is running",
	"Another analytics send process is running, exiting": "Another analytics send process is running, exiting",
	"Stale pid file found, continuing": "Stale pid file found, continuing",
	"Writing new pid file: %s": "Writing new pid file: %s",
	"Found %%s event": {
		"one": "Found %%s event",
		"other": "Found %%s events"
	},
	"Sending event: %s": "Sending event: %s",
	"Error sending event:": "Error sending event:",
	"Event sent successfully": "Event sent successfully",
	"Removing event: %s": "Removing event: %s",
	"Event was not sent successfully": "Event was not sent successfully",
	"Expected HTTP status code %s, got %s": "Expected HTTP status code %s, got %s",
	"Deleting pid file: %s": "Deleting pid file: %s",
	"All events processed": "All events processed",
	"Press ENTER to redraw prompt": "Press ENTER to redraw prompt",
	"Error communicating with the server: %s": "Error communicating with the server: %s",
	"Server did not return a session cookie": "Server did not return a session cookie",
	"Invalid username or password. If you have forgotten your password, please visit %s.": "Invalid username or password. If you have forgotten your password, please visit %s.",
	"Invalid server response": "Invalid server response",
	"Error logging out from server: %s": "Error logging out from server: %s",
	"Session file \"%s\" is not writable": "Session file \"%s\" is not writable",
	"Please ensure the Titanium CLI has access to modify this file.": "Please ensure the Titanium CLI has access to modify this file.",
	"Directory \"%s\" is not writable": "Directory \"%s\" is not writable",
	"Please ensure the Titanium CLI has access to this directory.": "Please ensure the Titanium CLI has access to this directory.",
	"The Command Line Tools are not installed": "The Command Line Tools are not installed",
	"Titanium requires that the Command Line Tools be installed to develop __native Android modules__.": "Titanium requires that the Command Line Tools be installed to develop __native Android modules__.",
	"You can install them from the Xcode Preferences > Downloads tab or by visiting": "You can install them from the Xcode Preferences > Downloads tab or by visiting",
	"Copying %s => %s": "Copying %s => %s",
	"Symlinking %s => %s": "Symlinking %s => %s",
	"Resizing images: %s": "Resizing images: %s",
	"Java Development Kit not installed.": "Java Development Kit not installed.",
	"Mac OS X 10.7 (Lion) and newer do not include the JDK and must be manually downloaded and installed from %s.": "Mac OS X 10.7 (Lion) and newer do not include the JDK and must be manually downloaded and installed from %s.",
	"JDK (Java Development Kit) not installed.": "JDK (Java Development Kit) not installed.",
	"If you already have installed the JDK, verify your __JAVA_HOME__ environment variable is correctly set.": "If you already have installed the JDK, verify your __JAVA_HOME__ environment variable is correctly set.",
	"The JDK is required for must be manually downloaded and installed from %s.": "The JDK is required for must be manually downloaded and installed from %s.",
	"Unable to find JDK (Java Development Kit) programs: %s": "Unable to find JDK (Java Development Kit) programs: %s",
	"Please verify your __JAVA_HOME__ environment variable is correctly set to the JDK install location.": "Please verify your __JAVA_HOME__ environment variable is correctly set to the JDK install location.",
	"__JAVA_HOME__ is currently set to \"%s\".": "__JAVA_HOME__ is currently set to \"%s\".",
	"Please set the __JAVA_HOME__ is set to the JDK install location and not the JRE (Java Runtime Environment).": "Please set the __JAVA_HOME__ is set to the JDK install location and not the JRE (Java Runtime Environment).",
	"The __JAVA_HOME__ must point to the JDK and not the JRE (Java Runtime Environment).": "The __JAVA_HOME__ must point to the JDK and not the JRE (Java Runtime Environment).",
	"You may want to reinstall the JDK by downloading it from %s.": "You may want to reinstall the JDK by downloading it from %s.",
	"Unable to find a valid Java installation containing a libjvm.so": "Unable to find a valid Java installation containing a libjvm.so",
	"Did you mean this?": "Did you mean this?",
	"day": {
		"one": "day",
		"other": "days"
	},
	"hour": {
		"one": "hour",
		"other": "hours"
	},
	"minute": {
		"one": "minute",
		"other": "minutes"
	},
	"second": {
		"one": "second",
		"other": "seconds"
	},
	"Looking for Titanium module id=%s version=%s platform=%s deploy-type=%s": "Looking for Titanium module id=%s version=%s platform=%s deploy-type=%s",
	"Found incompatible Titanium module id=%s version=%s platform=%s deploy-type=%s": "Found incompatible Titanium module id=%s version=%s platform=%s deploy-type=%s",
	"Found better matching module id=%s version=%s platform=%s deploy-type=%s path=%s": "Found better matching module id=%s version=%s platform=%s deploy-type=%s path=%s",
	"Found Titanium module id=%s version=%s platform=%s deploy-type=%s path=%s": "Found Titanium module id=%s version=%s platform=%s deploy-type=%s path=%s",
	"Could not find Titanium module id=%s version=%s platform=%s deploy-type=%s": "Could not find Titanium module id=%s version=%s platform=%s deploy-type=%s",
	"Installing module: %s": "Installing module: %s",
	"Failed to unzip module \"%s\"": "Failed to unzip module \"%s\"",
	"Detecting modules in %s": "Detecting modules in %s",
	"Detected %s module: %s %s @ %s": "Detected %s module: %s %s @ %s",
	"Looking for Titanium plugin id=%s version=%s": "Looking for Titanium plugin id=%s version=%s",
	"Found Titanium plugin id=%s version=%s ": "Found Titanium plugin id=%s version=%s ",
	"Could not find Titanium plugin id=%s version=%s": "Could not find Titanium plugin id=%s version=%s",
	"Detecting plugins in %s": "Detecting plugins in %s",
	"Detected plugin: %s @ %s": "Detected plugin: %s @ %s",
	"Detected plugin: %s %s @ %s": "Detected plugin: %s %s @ %s"
}
